package read;
import java.io.FileReader;
import java.io.FileNotFoundException;
import java.io.IOException;

public class FileReaderEx {
    public static void main(String[] args) {
        // Using try-with-resources to ensure FileReader is properly closed
        try (FileReader fileReader = new FileReader("herons.txt")) { 
            
            int c; // Variable to store character data read from the file
            
            // Read characters one by one until end of file (-1) is reached
            while ((c = fileReader.read()) != -1) {
                System.out.print((char) c); // Convert int to char and print
            }

        } catch (FileNotFoundException e) {  
            // Handles case where file is missing or incorrectly named
            System.err.println("Error: File not found - " + e.getMessage());
        } catch (IOException e) {  
            // Handles other I/O errors (e.g., read failure)
            System.err.println("Error reading file: " + e.getMessage());
        }

        /*
         * NOTE: If we did NOT use try-with-resources, we would need to manually close the file.
         * The code below demonstrates how to do this properly:
         */

        /*
        FileReader fileReader = null;
        try {
            fileReader = new FileReader("fileReader.txt");
            int c;
            while ((c = fileReader.read()) != -1) {
                System.out.print((char) c);
            }
        } catch (FileNotFoundException e) {
            System.err.println("Error: File not found - " + e.getMessage());
        } catch (IOException e) {
            System.err.println("Error reading file: " + e.getMessage());
        } finally {
            // Ensuring the fileReader is closed properly in the finally block
            if (fileReader != null) {
                try {
                    fileReader.close();
                } catch (IOException e) {
                    System.err.println("Error closing file: " + e.getMessage());
                }
            }
        }
        */

    }
}

